Crate psrgbt

Crate psrgbt 

Structs

OpoutAndOpids
Terminal

Enums

CommitError
DbcPsbtError
Errors processing DBC-related proprietary PSBT keys and their values.
EmbedError
MpcPsbtError
Errors processing MPC-related proprietary PSBT keys and their values.
OpretKeyError
Errors processing opret-related proprietary PSBT keys and their values.
RgbPsbtError
Errors processing RGB-related proprietary PSBT keys and their values.
TapretKeyError
Errors processing tapret-related proprietary PSBT keys and their values.
TerminalParseError

Constants

PSBT_GLOBAL_RGB_CLOSE_METHOD
Proprietary key subtype for storing information on which close method should be used.
PSBT_GLOBAL_RGB_CONSUMED_BY
Proprietary key subtype for storing RGB input allocation and ID of the transition spending it.
PSBT_GLOBAL_RGB_TAP_HOST_CHANGE
Proprietary key subtype to signal that tapret host has been put on change.
PSBT_GLOBAL_RGB_TRANSITION
Proprietary key subtype for storing RGB state transition in global map.
PSBT_MPC_PREFIX
PSBT proprietary key prefix used for MPC.
PSBT_MPC_PREFIX_STR
PSBT_OPRET_PREFIX
PSBT proprietary key prefix used for opret commitment.
PSBT_OPRET_PREFIX_STR
PSBT_OUT_MPC_COMMITMENT
The final multi-protocol commitment value.
PSBT_OUT_MPC_ENTROPY
Proprietary key subtype for storing MPC entropy constant.
PSBT_OUT_MPC_MESSAGE
Proprietary key subtype for storing MPC single commitment message under some protocol in global map.
PSBT_OUT_MPC_MIN_TREE_DEPTH
Proprietary key subtype for storing MPC requirement for a minimal tree size.
PSBT_OUT_MPC_PROOF
The multi-protocol commitment proof.
PSBT_OUT_OPRET_COMMITMENT
Proprietary key subtype holding 32-byte commitment which will be put into opret data.
PSBT_OUT_OPRET_HOST
Proprietary key subtype marking PSBT outputs which may host opret commitment.
PSBT_OUT_TAPRET_COMMITMENT
Proprietary key subtype holding 32-byte commitment which will be put into tapret tweak.
PSBT_OUT_TAPRET_HOST
Proprietary key subtype marking PSBT outputs which may host tapreturn commitment.
PSBT_OUT_TAPRET_PROOF
Proprietary key subtype holding merkle branch path to tapreturn tweak inside the taptree structure.
PSBT_RGB_PREFIX
PSBT proprietary key prefix used for RGB.
PSBT_RGB_PREFIX_STR
PSBT_TAPRET_PREFIX
PSBT proprietary key prefix used for tapreturn commitment.
PSBT_TAPRET_PREFIX_STR

Traits

DbcPsbtProof
RgbOutExt
RgbPropKeyExt
Extension trait for static functions returning RGB-related proprietary keys.
RgbPsbtExt