pub enum DbcPsbtError {
NoHostOutput,
NoProperOutput(CloseMethod),
AlreadyPresent,
TxOutputsModifiable,
Mpc(MpcPsbtError),
Tapret(TapretKeyError),
Opret(OpretKeyError),
}Expand description
Errors processing DBC-related proprietary PSBT keys and their values.
Variants
NoHostOutput
the first output valid for a DBC commitment is not marked as a commitment host.
NoProperOutput(CloseMethod)
the transactions contains no output valid for {0} DBC commitment.
AlreadyPresent
DBC commitment is already present.
TxOutputsModifiable
transaction outputs are marked as modifiable, thus deterministic bitcoin commitment can’t be created.
Mpc(MpcPsbtError)
MPC PSBT error
Tapret(TapretKeyError)
Tapret key error
Opret(OpretKeyError)
Opret key error