Structs
Enums
- Commit
Error - DbcPsbt
Error - Errors processing DBC-related proprietary PSBT keys and their values.
- Embed
Error - MpcPsbt
Error - Errors processing MPC-related proprietary PSBT keys and their values.
- Opret
KeyError - Errors processing opret-related proprietary PSBT keys and their values.
- RgbPsbt
Error - Errors processing RGB-related proprietary PSBT keys and their values.
- Tapret
KeyError - Errors processing tapret-related proprietary PSBT keys and their values.
- Terminal
Parse Error
Constants
- PSBT_
GLOBAL_ RGB_ CLOSE_ METHOD - Proprietary key subtype for storing information on which close method should be used.
- PSBT_
GLOBAL_ RGB_ CONSUMED_ BY - Proprietary key subtype for storing RGB input allocation and ID of the transition spending it.
- PSBT_
GLOBAL_ RGB_ TAP_ HOST_ CHANGE - Proprietary key subtype to signal that tapret host has been put on change.
- PSBT_
GLOBAL_ RGB_ TRANSITION - Proprietary key subtype for storing RGB state transition in global map.
- PSBT_
MPC_ PREFIX - PSBT proprietary key prefix used for MPC.
- PSBT_
MPC_ PREFIX_ STR - PSBT_
OPRET_ PREFIX - PSBT proprietary key prefix used for opret commitment.
- PSBT_
OPRET_ PREFIX_ STR - PSBT_
OUT_ MPC_ COMMITMENT - The final multi-protocol commitment value.
- PSBT_
OUT_ MPC_ ENTROPY - Proprietary key subtype for storing MPC entropy constant.
- PSBT_
OUT_ MPC_ MESSAGE - Proprietary key subtype for storing MPC single commitment message under some protocol in global map.
- PSBT_
OUT_ MPC_ MIN_ TREE_ DEPTH - Proprietary key subtype for storing MPC requirement for a minimal tree size.
- PSBT_
OUT_ MPC_ PROOF - The multi-protocol commitment proof.
- PSBT_
OUT_ OPRET_ COMMITMENT - Proprietary key subtype holding 32-byte commitment which will be put into opret data.
- PSBT_
OUT_ OPRET_ HOST - Proprietary key subtype marking PSBT outputs which may host opret commitment.
- PSBT_
OUT_ TAPRET_ COMMITMENT - Proprietary key subtype holding 32-byte commitment which will be put into tapret tweak.
- PSBT_
OUT_ TAPRET_ HOST - Proprietary key subtype marking PSBT outputs which may host tapreturn commitment.
- PSBT_
OUT_ TAPRET_ PROOF - Proprietary key subtype holding merkle branch path to tapreturn tweak inside the taptree structure.
- PSBT_
RGB_ PREFIX - PSBT proprietary key prefix used for RGB.
- PSBT_
RGB_ PREFIX_ STR - PSBT_
TAPRET_ PREFIX - PSBT proprietary key prefix used for tapreturn commitment.
- PSBT_
TAPRET_ PREFIX_ STR
Traits
- DbcPsbt
Proof - RgbOut
Ext - RgbProp
KeyExt - Extension trait for static functions returning RGB-related proprietary keys.
- RgbPsbt
Ext